/**
 * @file
 *
 * MerlinOne Entity Browser integration
 */
(function ($, Drupal) {

  'use strict';

  function getHost(url) {
    var l = document.createElement('a');
    l.href = url;
    return l.hostname;
  }

  Drupal.behaviors.merlinOneEntityBrowserSearch = {
    attach: function (context, settings) {
      // Parent window's MerlinOne processing handler.
      var MerlinOne = window.parent.MerlinOne;

      var merlinSettings = settings.merlinone,
        mxHost = merlinSettings.mx_host;

      // Hold the final list of items to submit.
      var finalItems = [];

      // Search frame
      var $searchFrame = $(context).find('.merlinone-search-iframe').once('merlinOneEntityBrowserSearch');
      if ($searchFrame.length) {
        // Hidden input to hold the JSON response from Merlin
        var $merlinMessageResponse = $(context).find('input[name=merlinone_items]');

        // Disable submit button until we get data
        var $submit = $(context).find('.is-entity-browser-submit');
        $submit.prop('disabled', true);

        var $throbber = $(
          '<div class="ajax-progress ajax-progress-throbber">' +
            '<div class="throbber">&nbsp;</div>' +
            '<div class="message">' + Drupal.t('Please wait...') + '</div>' +
          '</div>'
        ).hide();
        $submit.after($throbber);

        // Display throbber when button is clicked
        $submit.on('click', function () {
          $throbber.show();
        });

        // Items processed callback.
        var itemsProcessed = function (items) {
          finalItems = finalItems.concat(items);
          $merlinMessageResponse.val(JSON.stringify(finalItems));
          $submit.prop('disabled', false);
          $throbber.hide();
        };

        // Receive selected item information.
        var messageHandler = function (e) {
          if (e.data && getHost(e.origin) === mxHost) {
            var response = JSON.parse(e.data);
            if (response.data && response.message) {
              if (response.message !== 'mxDidShareAssets') return;

              if (response.data.assets) {
                $throbber.show();
                MerlinOne.prepareMedia(response.data.assets, response.data.transaction, merlinSettings, itemsProcessed);
              }
              else {
                $merlinMessageResponse.val('');
                $submit.prop('disabled', false);
              }
            }
          }
        };

        // Attach listener
        window.addEventListener('message', messageHandler);
      }
    }
  };

})(jQuery, Drupal);
